@@ -85,12 +85,21 @@ class CommandLineTool(object):
             pass
 
     def input_password(self, prompt):
-        """Ask for a password to the user.
-
-        This mostly exists to ease the testing process.
+        """Retrieve password from input.
         """
+        return self.pass_from_pipe() or getpass.getpass(prompt)
 
-        return getpass.getpass(prompt)
+    @staticmethod
+    def pass_from_pipe(cls):
+        """Return password from pipe if not on TTY, else False.
+        """
+        is_pipe = not sys.stdin.isatty()
+        return is_pipe and cls.strip_last_newline(sys.stdin.read())
+
+    @staticmethod
+    def strip_last_newline(str):
+        """Strip one last newline, if present."""
+        return str[:-str.endswith('\n')]
 
     def output_password(self, password):
         """Output the password to the user.
